@@ -1,6 +1,7 @@
 import * as React from 'react';
 import { match as RMatch } from 'react-router';
-import { history, useAccessReview } from '@console/internal/components/utils';
+import { useTranslation } from 'react-i18next';
+import { history, useAccessReview, Page } from '@console/internal/components/utils';
 import { ALL_NAMESPACES_KEY } from '@console/shared';
 import { NamespaceDetails, projectMenuActions } from '@console/internal/components/namespace';
 import { ProjectModel, RoleBindingModel } from '@console/internal/models';
@@ -10,7 +11,7 @@ import { withStartGuide } from '@console/internal/components/start-guide';
 import NamespacedPage, { NamespacedPageVariants } from '../../NamespacedPage';
 import ProjectAccessPage from '../../project-access/ProjectAccessPage';
 import { Helmet } from 'react-helmet';
-import ProjectListPage from '../ProjectListPage';
+import CreateProjectListPage from '../CreateProjectListPage';
 
 export const PROJECT_DETAILS_ALL_NS_PAGE_URI = '/project-details/all-namespaces';
 
@@ -32,6 +33,7 @@ export const PageContents: React.FC<MonitoringPageProps> = ({
   match,
   ...props
 }) => {
+  const { t } = useTranslation();
   const activeNamespace = match.params.ns;
 
   const canListRoleBindings = useAccessReview({
@@ -48,6 +50,26 @@ export const PageContents: React.FC<MonitoringPageProps> = ({
     namespace: activeNamespace,
   });
 
+  const pages: Page[] = [
+    {
+      href: '',
+      name: t('devconsole~Overview'),
+      component: ProjectDashboard,
+    },
+    {
+      href: 'details',
+      name: t('devconsole~Details'),
+      component: NamespaceDetails,
+    },
+  ];
+  if (canListRoleBindings && canCreateRoleBindings) {
+    pages.push({
+      href: 'access',
+      name: t('devconsole~Project access'),
+      component: ProjectAccessPage,
+    });
+  }
+
   return !noProjectsAvailable && activeNamespace ? (
     <DetailsPage
       {...props}
@@ -58,45 +80,33 @@ export const PageContents: React.FC<MonitoringPageProps> = ({
       kindObj={ProjectModel}
       menuActions={projectMenuActions}
       customData={{ activeNamespace, hideHeading: true }}
-      pages={[
-        {
-          href: '',
-          name: 'Overview',
-          component: ProjectDashboard,
-        },
-        {
-          href: 'details',
-          name: 'Details',
-          component: NamespaceDetails,
-        },
-        canListRoleBindings &&
-          canCreateRoleBindings && {
-            href: 'access',
-            name: 'Project Access',
-            component: ProjectAccessPage,
-          },
-      ]}
+      pages={pages}
     />
   ) : (
-    <ProjectListPage title="Project Details">Select a project to view its details</ProjectListPage>
+    <CreateProjectListPage title="Project Details">
+      {t('devconsole~Select a Project to view its details')}
+    </CreateProjectListPage>
   );
 };
 
 const PageContentsWithStartGuide = withStartGuide(PageContents);
 
-export const ProjectDetailsPage: React.FC<MonitoringPageProps> = (props) => (
-  <>
-    <Helmet>
-      <title>Project Details</title>
-    </Helmet>
-    <NamespacedPage
-      hideApplications
-      variant={NamespacedPageVariants.light}
-      onNamespaceChange={handleNamespaceChange}
-    >
-      <PageContentsWithStartGuide {...props} />
-    </NamespacedPage>
-  </>
-);
+export const ProjectDetailsPage: React.FC<MonitoringPageProps> = (props) => {
+  const { t } = useTranslation();
+  return (
+    <>
+      <Helmet>
+        <title>{t('devconsole~Project Details')}</title>
+      </Helmet>
+      <NamespacedPage
+        hideApplications
+        variant={NamespacedPageVariants.light}
+        onNamespaceChange={handleNamespaceChange}
+      >
+        <PageContentsWithStartGuide {...props} />
+      </NamespacedPage>
+    </>
+  );
+};
 
 export default ProjectDetailsPage;
