@@ -1,12 +1,13 @@
 import { OrderedSet } from 'immutable';
 import { CommonData, VMSettingsField, VMWizardProps } from '../../types';
-import { asHidden, asRequired } from '../../utils/utils';
+import { asHidden, asRequired, asDisabled } from '../../utils/utils';
 import { ProvisionSource } from '../../../../constants/vm/provision-source';
 import { InitialStepStateGetter, VMSettings } from './types';
+import { TemplateSupport } from '../../../../constants/vm-templates/support';
 
 export const getInitialVmSettings = (data: CommonData): VMSettings => {
   const {
-    data: { isCreateTemplate, isProviderImport },
+    data: { isCreateTemplate, isProviderImport, initialData },
   } = data;
 
   const hiddenByProvider = asHidden(isProviderImport, VMWizardProps.isProviderImport);
@@ -22,11 +23,21 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
     [VMSettingsField.NAME]: {
       isRequired: asRequired(true),
       validations: [],
+      value: initialData.name || undefined,
     },
     [VMSettingsField.HOSTNAME]: {},
     [VMSettingsField.DESCRIPTION]: {},
+    [VMSettingsField.TEMPLATE_PROVIDER]: {
+      isRequired: asRequired(isCreateTemplate),
+      isHidden: asHidden(!isCreateTemplate),
+    },
+    [VMSettingsField.TEMPLATE_SUPPORTED]: {
+      isHidden: asHidden(!isCreateTemplate),
+      value: TemplateSupport.NO_SUPPORT.getValue(),
+    },
     [VMSettingsField.OPERATING_SYSTEM]: {
       isRequired: asRequired(true),
+      isDisabled: asDisabled(!isCreateTemplate && !isProviderImport, 'create-vm-flow'),
     },
     [VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE]: {
       value: false,
@@ -49,13 +60,11 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
     [VMSettingsField.PROVISION_SOURCE_TYPE]: {
       isHidden: hiddenByProviderOrCloneCommonBaseDiskImage,
       isRequired: asRequired(!isProviderImport),
-      sources: OrderedSet(
-        [
-          ProvisionSource.PXE,
-          ProvisionSource.URL,
-          ProvisionSource.CONTAINER,
-          ProvisionSource.DISK,
-        ].map((source) => source.getValue()),
+      sources: OrderedSet(ProvisionSource.getAdvancedWizardSources().map((s) => s.getValue())),
+      initialized: !(
+        initialData.source?.url ||
+        initialData.source?.container ||
+        (initialData.source?.pvcName && initialData.source?.pvcNamespace)
       ),
     },
     [VMSettingsField.CONTAINER_IMAGE]: {
@@ -65,9 +74,14 @@ export const getInitialVmSettings = (data: CommonData): VMSettings => {
       isHidden: hiddenByProviderOrCloneCommonBaseDiskImage,
     },
     [VMSettingsField.START_VM]: {
-      value: false,
+      value: !!initialData.startVM,
       isHidden: hiddenByProviderOrTemplate,
     },
+    [VMSettingsField.CLONE_PVC_NS]: {
+      isHidden: hiddenByProviderOrCloneCommonBaseDiskImage,
+    },
+    [VMSettingsField.CLONE_PVC_NAME]: {},
+    [VMSettingsField.DEFAULT_STORAGE_CLASS]: {},
   };
 
   Object.keys(fields).forEach((k) => {
