@@ -4,9 +4,12 @@ import { TechPreviewBadge } from '@console/shared';
 
 import './PipelineBuilderHeader.scss';
 import { useTranslation } from 'react-i18next';
+import { usePipelineTechPreviewBadge } from '../../../utils/hooks';
 
-const PipelineBuilderHeader: React.FC = () => {
+const PipelineBuilderHeader: React.FC<{ namespace: string }> = ({ namespace }) => {
   const { t } = useTranslation();
+  const badge = usePipelineTechPreviewBadge(namespace);
+
   return (
     <div className="odc-pipeline-builder-header">
       <Flex className="odc-pipeline-builder-header__content">
@@ -15,9 +18,11 @@ const PipelineBuilderHeader: React.FC = () => {
             {t('pipelines-plugin~Pipeline builder')}
           </h1>
         </FlexItem>
-        <FlexItem>
-          <TechPreviewBadge />
-        </FlexItem>
+        {badge && (
+          <FlexItem>
+            <TechPreviewBadge />
+          </FlexItem>
+        )}
       </Flex>
     </div>
   );
